@@ -1,7 +1,7 @@
 package App::SetScreensaverTimeout;
 
-our $DATE = '2014-11-28'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2014-11-30'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -15,7 +15,7 @@ our %SPEC;
 
 $SPEC{get_screensaver_timeout} = {
     v => 1.1,
-    summary => 'Get screensaver timeout',
+    summary => 'Get screensaver timeout (in minutes)',
     description => <<'_',
 
 Provide a common way to get screensaver timeout setting. Support several screen
@@ -46,7 +46,7 @@ sub get_screensaver_timeout {
         return [500, "gsettings get failed: $!"] if $?;
         $res =~ /^uint32\s+(\d+)$/
             or return [500, "Can't parse gsettings get output"];
-        return [200, "OK", $1, {'func.screensaver'=>'gnome-screensaver'}];
+        return [200, "OK", $1/60, {'func.screensaver'=>'gnome-screensaver'}];
     }
 
     if (proc_exists(name=>"xscreensaver")) {
@@ -55,7 +55,7 @@ sub get_screensaver_timeout {
 
         $ct =~ /^timeout:\s*(\d+):(\d+):(\d+)\s*$/m
             or return [500, "Can't get timeout setting in $path"];
-        return [200, "OK", $1*3600+$2*60+$3,
+        return [200, "OK", ($1*3600+$2*60+$3)/60,
                 {'func.screensaver'=>'xscreensaver'}];
     }
 
@@ -146,14 +146,14 @@ App::SetScreensaverTimeout - Set screensaver timeout
 
 =head1 VERSION
 
-This document describes version 0.03 of App::SetScreensaverTimeout (from Perl distribution App-SetScreensaverTimeout), released on 2014-11-28.
+This document describes version 0.04 of App::SetScreensaverTimeout (from Perl distribution App-SetScreensaverTimeout), released on 2014-11-30.
 
 =head1 FUNCTIONS
 
 
 =head2 get_screensaver_timeout() -> [status, msg, result, meta]
 
-Get screensaver timeout.
+Get screensaver timeout (in minutes).
 
 Provide a common way to get screensaver timeout setting. Support several screen
 savers (see C<set_screensaver_timeout>).
